// Summary Information
#define PID_TITLE        2
#define PID_SUBJECT      3
#define PID_AUTHOR       4
#define PID_KEYWORDS     5
#define PID_COMMENTS     6
#define PID_TEMPLATE     7
#define PID_LASTAUTHOR   8
#define PID_REVNUMBER    9
#define PID_EDITTIME     10
#define PID_LASTPRINTED  11
#define PID_CREATE_DTM   12
#define PID_LASTSAVE_DTM 13
#define PID_PAGECOUNT    14
#define PID_WORDCOUNT    15
#define PID_CHARCOUNT    16
#define PID_THUMBNAIL    17
#define PID_APPNAME      18
// #define PID_SECURITY     19

 // Document Summary Information
#define PID_CATEGORY     2
#define PID_PRESFORMAT   3
#define PID_BYTECOUNT    4
#define PID_LINECOUNT    5
#define PID_PARCOUNT     6
#define PID_SLIDECOUNT   7
#define PID_NOTECOUNT    8
#define PID_HIDDENCOUNT  9
#define PID_MMCLIPCOUNT  10
#define PID_SCALE        11
#define PID_HEADINGPAIR  12
#define PID_DOCPARTS     13
#define PID_MANAGER      14
#define PID_COMPANY      15
#define PID_LINKSDIRTY   16
#define PID_CHARCOUNT2   17
